@@ -11,6 +11,8 @@ x, ORBIT_ROOT_OBJECT(x)->refs); CORBA_Object_release(x, y); })
 x, ORBIT_ROOT_OBJECT(x)->refs); CORBA_Object_duplicate(x, y); })
 #endif
 
+#define FREE_MARKER_IS_ALLOCATED 0xfefefefe
+
 /* The memory chunk stuff */
 
 #define ALLOCATOR_DEFINITION
@@ -82,6 +84,7 @@ ORBit_alloc_2(size_t block_size,
 #endif
 	block->free = freefunc;
 	block->func_data = func_data;
+	block->free_marker= FREE_MARKER_IS_ALLOCATED;
 
 	return MEMINFO_TO_PTR(block);
 }
@@ -101,7 +104,7 @@ ORBit_alloc_2(size_t block_size,
  */
 
 void
-ORBit_free(gpointer mem, CORBA_boolean free_strings)
+ORBit_free(gpointer mem, CORBA_boolean ignore)
 {
 	ORBit_mem_info *block;
 
@@ -110,6 +113,12 @@ ORBit_free(gpointer mem, CORBA_boolean free_strings)
 
 	block = PTR_TO_MEMINFO(mem);
 
+	/* This block has not been allocated by CORBA_alloc. Instead
+         * it is memory in the receive buffer, that has been used in
+         * demarshalling. Let's just return. */
+	if (block->free_marker != FREE_MARKER_IS_ALLOCATED)
+		return;
+
 #ifdef ORBIT_DEBUG
 	g_assert(block->magic == 0xdeadbeef);
 #endif
@@ -130,7 +139,7 @@ ORBit_free(gpointer mem, CORBA_boolean free_strings)
 #endif
 
 		for(i = 0, x = mem; i < (gulong)block->func_data; i++)
-			x = block->free(x, my_data, free_strings);
+			x = block->free(x, my_data, CORBA_TRUE);
 
 		if((gpointer)block->free == (gpointer)ORBit_free_via_TypeCode)
 			/* ((guchar *)block) -= sizeof(CORBA_TypeCode); */
@@ -145,7 +154,7 @@ ORBit_free(gpointer mem, CORBA_boolean free_strings)
 /* These aren't currently used... */
 
 gpointer
-ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
+ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean ignore)
 {
 	CORBA_TypeCode tc = *(CORBA_TypeCode *)tcp, subtc;
 	int i;
@@ -182,7 +191,7 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		for(i = 0; i < tc->sub_parts; i++) {
 			subtc = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)tc->subtypes[i], NULL);
 			mem = ORBit_free_via_TypeCode(mem, &subtc,
-						      free_strings);
+						      CORBA_TRUE);
 		}
 		retval = mem;
 		break;
@@ -197,7 +206,7 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		        sz = MAX(sz, ORBit_gather_alloc_info(tc->subtypes[i]));
 		    }
 		    mem = ALIGN_ADDRESS(mem, al);
-		    ORBit_free_via_TypeCode(mem, &subtc, free_strings);
+		    ORBit_free_via_TypeCode(mem, &subtc, CORBA_TRUE);
 		    /* the end of the body (subtc) may not be the
 		     * same as the end of the union */
 		    retval = (guchar *)mem + sz;
@@ -205,7 +214,6 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		break;
 	case CORBA_tk_wstring:
 	case CORBA_tk_string:
-		if(free_strings)
 			CORBA_free(*(char **)mem);
 		retval = (guchar *)mem + sizeof(char *);
 		break;
@@ -222,13 +230,13 @@ ORBit_free_via_TypeCode(gpointer mem, gpointer tcp, gboolean free_strings)
 		for(i = 0; i < tc->length; i++) {
 			subtc = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)tc->subtypes[0], NULL);
 			mem = ORBit_free_via_TypeCode(mem, &subtc,
-						      free_strings);
+						      CORBA_TRUE);
 		}
 		retval = mem;
 		break;
 	case CORBA_tk_alias:
 		subtc = (CORBA_TypeCode)CORBA_Object_duplicate((CORBA_Object)tc->subtypes[0], NULL);
-		retval = ORBit_free_via_TypeCode(mem, &subtc, free_strings);
+		retval = ORBit_free_via_TypeCode(mem, &subtc, CORBA_TRUE);
 		break;
 	default:
 		/* NB. alignment != alloc size */
