@@ -150,8 +150,8 @@ dynany_invalidate (DynAny *d,
 			g_assert (!d->any->_release);
 		}
 
-		CORBA_Object_release ((CORBA_Object) d->any->_type, ev);
-		CORBA_free (d->any);
+		if (d->any->_release) 
+			CORBA_free (d->any);
 		d->any = NULL;
 	}
 
@@ -1613,12 +1613,15 @@ DynamicAny_DynSequence_get_elements (DynamicAny_DynSequence obj,
 	retval = CORBA_sequence_DynamicAny_DynAny_AnySeq__alloc ();
 	retval->_buffer = CORBA_sequence_DynamicAny_DynAny_AnySeq_allocbuf (
 		s->_length);
+	retval->_length = s->_length;
 	subtc = dynany->any->_type->subtypes [0];
 
 	for (i = 0; i < s->_length; i++) {
 		CORBA_any *any = CORBA_any__alloc ();
 		gpointer   to;
 
+		retval->_buffer [i] = any;
+
 		any->_type = (CORBA_TypeCode) CORBA_Object_duplicate (
 			(CORBA_Object) subtc, ev);
 		to = any->_value = ORBit_demarshal_allocate_mem (subtc, 1);
