@@ -95,6 +95,7 @@ static void ORBit_rc_load(const char *rcfile, ORBit_orb_options *options)
 	FILE *fp;
 	GHashTable *read_options;
 	ORBit_orb_options *search;
+	char buf[1024];
 
 	fp=fopen(rcfile, "r");
 
@@ -103,37 +104,31 @@ static void ORBit_rc_load(const char *rcfile, ORBit_orb_options *options)
 
 	read_options=g_hash_table_new(g_str_hash, g_str_equal);
 
-	while(!feof(fp)) {
-		char buf[1024];
+	while(fgets(buf, 1024, fp)) {
+		guchar *bptr, *tmp, *key, *data;
+		size_t start, len;
+		if(buf[0]=='#')
+			continue;
+		
+		bptr=buf;
+		tmp=strpbrk(bptr, " \t\n=");
+		if(tmp==NULL) continue;
+		*tmp++='\0';
+		key=g_strdup(bptr);
+		bptr=tmp;
 
-		if(fgets(buf, 1024, fp)!=NULL) {
-			guchar *bptr, *tmp, *key, *data;
-			size_t start, len;
-
-			if(buf[0]=='#')
-				continue;
-			
-			bptr=buf;
-			tmp=strpbrk(bptr, " \t\n=");
-			if(tmp==NULL) continue;
-			*tmp++='\0';
-			key=g_strdup(bptr);
-			bptr=tmp;
-
-			start=0;
-			while(bptr+start != '\0' &&
-			     (isspace(bptr[start]) || bptr[start]=='='))
-				start++;
-			len=strcspn(bptr+start, " \t\n");
-			bptr[start+len]='\0';
-			if(len>0) {
-				data=g_strdup(bptr+start);
-			} else {
-				data=g_strdup("TRUE");
-			}
-
-			g_hash_table_insert(read_options, key, data);
+		start=0;
+		while(bptr+start != '\0' &&
+		     (isspace(bptr[start]) || bptr[start]=='='))
+			start++;
+		len=strcspn(bptr+start, " \t\n");
+		bptr[start+len]='\0';
+		if(len>0) {
+			data=g_strdup(bptr+start);
+		} else {
+			data=g_strdup("TRUE");
 		}
+		g_hash_table_insert(read_options, key, data);
 	}
 	fclose(fp);
 
@@ -1038,7 +1033,7 @@ CORBA_Object CORBA_ORB_resolve_initial_references(CORBA_ORB orb, CORBA_ORB_Objec
 			CORBA_PolicyList policies  = {1,1,policybuf,CORBA_FALSE};
 			PortableServer_POAManager poa_mgr;
 			/* The only non-default policy used by the RootPOA is IMPLICIT ACTIVATION */ 
-			policies._buffer[0]=
+			policies._buffer[0]= (CORBA_Policy)
 				PortableServer_POA_create_implicit_activation_policy(NULL,
 										     PortableServer_IMPLICIT_ACTIVATION,
 										     ev);			
@@ -1054,7 +1049,7 @@ CORBA_Object CORBA_ORB_resolve_initial_references(CORBA_ORB orb, CORBA_ORB_Objec
 					      &policies,
 					      ev);
 			CORBA_Object_duplicate(orb->root_poa, ev);
-			CORBA_Object_release(policies._buffer[0],ev);
+			CORBA_Object_release((CORBA_Object)policies._buffer[0],ev);
 		}
 
 		return CORBA_Object_duplicate(orb->root_poa, ev);
