@@ -879,6 +879,9 @@ PortableServer_POA_servant_to_reference(PortableServer_POA obj, PortableServer_S
 	}
 	retval = PortableServer_POA_id_to_reference(obj,orig_id,ev);
 
+	if( implicit && activate_able)
+		CORBA_free (orig_id);
+
 	return retval;
 }
 
