@@ -71,3 +71,34 @@ const struct CORBA_TypeCode_struct TC_wstring_struct=
 	{{{(ORBit_RootObject_Interface *)&ORBit_TypeCode_epv, CORBA_FALSE, -1}, ORBIT_PSEUDO_TYPECODE}, CORBA_tk_wstring, "wide string", "", 0, 0, NULL, NULL, NULL, NULL, -1, 0, 0, 0};
 const struct CORBA_TypeCode_struct TC_CORBA_NamedValue_struct=
 	{{{(ORBit_RootObject_Interface *)&ORBit_TypeCode_epv, CORBA_FALSE, -1}, ORBIT_PSEUDO_TYPECODE}, CORBA_tk_struct, "CORBA NamedValue", "", 0, 0, NULL, NULL, NULL, NULL, -1, 0, 0, 0};
+
+static const CORBA_TypeCode anon_subtypes_array7[] =
+{(CORBA_TypeCode) & TC_CORBA_string_struct};
+
+#if (TC_IMPL_TC_CORBA_Identifier_0 == '/')
+const struct CORBA_TypeCode_struct TC_CORBA_Identifier_struct =
+{
+   {
+      {(ORBit_RootObject_Interface *) & ORBit_TypeCode_epv, TRUE, -1}, ORBIT_PSEUDO_TYPECODE},
+   CORBA_tk_alias, "Identifier", "IDL:omg.org/CORBA/Identifier:1.0",
+   0, 1,
+   NULL,
+   (CORBA_TypeCode *) anon_subtypes_array7,
+   NULL,
+   CORBA_OBJECT_NIL, 0, -1, 0, 0
+};
+#endif
+
+#if (TC_IMPL_TC_CORBA_RepositoryId_0 == '/')
+const struct CORBA_TypeCode_struct TC_CORBA_RepositoryId_struct =
+{
+   {
+      {(ORBit_RootObject_Interface *) & ORBit_TypeCode_epv, TRUE, -1}, ORBIT_PSEUDO_TYPECODE},
+   CORBA_tk_alias, "RepositoryId", "IDL:omg.org/CORBA/RepositoryId:1.0",
+   0, 1,
+   NULL,
+   (CORBA_TypeCode *) anon_subtypes_array7,
+   NULL,
+   CORBA_OBJECT_NIL, 0, -1, 0, 0
+};
+#endif
