@@ -213,7 +213,9 @@ void testCompoundStruct(test_TestFactory factory,
   g_assert(strcmp(inoutArg.a.a,constants_STRING_INOUT_OUT)==0);
   g_assert(strcmp(outArg->a.a,constants_STRING_OUT)==0);
   g_assert(strcmp(retn->a.a,constants_STRING_RETN)==0);	
-
+  
+  CORBA_free(inArg.a.a);
+  CORBA_free(inoutArg.a.a);
   CORBA_free(outArg);
   CORBA_free(retn);  
   CORBA_Object_release(objref, ev);
@@ -441,6 +443,12 @@ void testVariableLengthArray(test_TestFactory factory,
 
   retn = test_ArrayServer_opStrArray(objref,inArg,inoutArg,&outArg,ev);
 
+  for(i=0;i<constants_SEQLEN;i++)
+	CORBA_free (inArg[i]); 
+
+  for(i=0;i<constants_SEQLEN;i++)
+        CORBA_free (inoutArg[i]);
+
   CORBA_free(outArg);
   CORBA_free(retn);
   CORBA_Object_release(objref, ev);
@@ -451,7 +459,7 @@ void testVariableLengthArray(test_TestFactory factory,
   for (n0 = 0; n0 < 2; n0++) {
 	for (n1 = 0; n1 < 3; n1++) {
 	  for (n2 = 0; n2 < 5; n2++) {
-		multidim[0][0][0] = CORBA_string_dup(constants_SEQ_STRING_INOUT_IN[0]);
+		multidim[n0][n1][n2] = CORBA_string_dup(constants_SEQ_STRING_INOUT_IN[0]);
 	  }
 	}
   }
@@ -496,10 +504,12 @@ void testAnyLong(test_TestFactory factory,
 
   if(CORBA_any_get_release(&inArg)){
 	CORBA_free(inArg._value);
+	CORBA_Object_release((CORBA_Object)inArg._type, ev);
   }
 
   if(CORBA_any_get_release(&inoutArg)){
 	CORBA_free(inoutArg._value);
+	CORBA_Object_release((CORBA_Object)inoutArg._type, ev);
   }
 
   CORBA_free(outArg);
@@ -542,10 +552,12 @@ void testAnyString(test_TestFactory factory,
 
   if(CORBA_any_get_release(&inArg)){
 	CORBA_free(inArg._value);
+	CORBA_Object_release((CORBA_Object)inArg._type, ev);
   }
 
   if(CORBA_any_get_release(&inoutArg)){
 	CORBA_free(inoutArg._value);
+	CORBA_Object_release((CORBA_Object)inoutArg._type, ev);
   }
 
   CORBA_free(outArg);
@@ -559,24 +571,28 @@ void testAnyStruct(test_TestFactory factory,
 				   CORBA_Environment *ev) {
   test_AnyServer objref;
   CORBA_any inArg, inoutArg, *outArg, *retn;
-  test_VariableLengthStruct inArgStruct, inoutArgStruct;
-
-  inArgStruct.a=(CORBA_char*)constants_STRING_IN; /* const cast */
-  inoutArgStruct.a = CORBA_string_dup(constants_STRING_INOUT_IN);
+  test_VariableLengthStruct inArgStruct; 
+  test_VariableLengthStruct * inoutArgStruct;
 
   g_print("Testing any with structs...\n");
+
   objref = test_TestFactory_getAnyServer(factory,ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
 
+  inoutArgStruct = test_VariableLengthStruct__alloc();
+  inArgStruct.a=(CORBA_char*)constants_STRING_IN; /* const cast */
   inArg._type = (CORBA_TypeCode)TC_test_VariableLengthStruct;
   inArg._value = &inArgStruct;
   CORBA_any_set_release(&inArg, CORBA_FALSE);
 
+
+  inoutArgStruct->a = CORBA_string_dup(constants_STRING_INOUT_IN);
   inoutArg._type = (CORBA_TypeCode)TC_test_VariableLengthStruct;
-  inoutArg._value = &inoutArgStruct;
-  CORBA_any_set_release(&inoutArg, CORBA_FALSE);
-  
+  inoutArg._value = inoutArgStruct;
+  CORBA_any_set_release(&inoutArg, CORBA_TRUE);
+
   retn = test_AnyServer_opAnyStruct(objref,&inArg,&inoutArg,&outArg,ev);
+
   
   g_assert(CORBA_TypeCode_equal(inArg._type,TC_test_VariableLengthStruct,ev));
   g_assert(strcmp((*(test_VariableLengthStruct*)inArg._value).a,constants_STRING_IN) == 0);
@@ -590,12 +606,16 @@ void testAnyStruct(test_TestFactory factory,
   g_assert(CORBA_TypeCode_equal(retn->_type,TC_test_VariableLengthStruct,ev) );
   g_assert(strcmp((*(test_VariableLengthStruct*)retn->_value).a,constants_STRING_RETN) == 0);
 
+
   if(CORBA_any_get_release(&inArg)){
+	/* This shouldn't be called */
 	CORBA_free(inArg._value);
+	CORBA_Object_release((CORBA_Object)inArg._type, ev);
   }
 
   if(CORBA_any_get_release(&inoutArg)){
 	CORBA_free(inoutArg._value);
+	CORBA_Object_release((CORBA_Object)inoutArg._type, ev);
   }
 
   CORBA_free(outArg);
@@ -603,6 +623,46 @@ void testAnyStruct(test_TestFactory factory,
 
   CORBA_Object_release(objref, ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
+
+}
+
+void testSequenceOfAny(test_TestFactory factory, 
+					   CORBA_Environment *ev) {
+  /* this test just checks the memory management for seq of any */
+
+  test_AnySeq anyseq;
+  int i;
+
+  g_print("Testing Sequence of Any...\n");
+
+  anyseq._buffer= CORBA_sequence_CORBA_any_allocbuf(2);
+  anyseq._length= 2;
+  
+  for (i=0;i<anyseq._length;i++){
+	anyseq._buffer[i]._type = (CORBA_TypeCode)TC_string;
+	anyseq._buffer[i]._value = &constants_STRING_IN;
+	CORBA_any_set_release(&anyseq._buffer[i], CORBA_FALSE);
+  }
+  
+  CORBA_free(anyseq._buffer);
+}
+
+/**
+   This test tests memory management of exceptions in anys
+ */
+void testAnyException(test_TestFactory factory, 
+					  CORBA_Environment *ev) {
+  test_AnyServer objref;
+  CORBA_any *inArg; 
+  test_TestException * testex;
+
+  inArg = CORBA_any__alloc();
+  testex = test_TestException__alloc();  
+  inArg->_type = (CORBA_TypeCode) TC_test_TestException;
+  inArg->_value = testex;
+  CORBA_any_set_release(inArg,CORBA_TRUE);
+
+  CORBA_free(inArg);
 }
 
 void testTypeCode(test_TestFactory factory, 
@@ -625,6 +685,10 @@ void testTypeCode(test_TestFactory factory,
   g_assert(CORBA_TypeCode_equal(outArg,TC_test_AnEnum,ev) );  
   g_assert(CORBA_TypeCode_equal(retn,TC_test_VariableLengthStruct,ev) );
 
+  CORBA_Object_release((CORBA_Object)inArg, ev);
+  CORBA_Object_release((CORBA_Object)inoutArg, ev);
+  CORBA_Object_release((CORBA_Object)outArg, ev);
+  CORBA_Object_release((CORBA_Object)retn, ev);
 
   CORBA_Object_release(objref, ev);
   g_assert(ev->_major == CORBA_NO_EXCEPTION);
@@ -634,7 +698,7 @@ int main(int argc, char *argv[]) {
   CORBA_Environment ev;
   CORBA_ORB orb;
   test_TestFactory factory;
-
+  int i;
   CORBA_exception_init(&ev);
   orb = CORBA_ORB_init(&argc, argv, "orbit-local-orb", &ev);
   g_assert(ev._major == CORBA_NO_EXCEPTION);
@@ -651,8 +715,9 @@ int main(int argc, char *argv[]) {
 	g_assert(ev._major == CORBA_NO_EXCEPTION);
   }
 
+  for(i=0;i<20;i++){
   testConst();
-  testAttribute(factory,&ev);
+  testAttribute(factory,&ev);  
   testString(factory,&ev);
   testLong(factory,&ev);
   testEnum(factory,&ev);
@@ -669,8 +734,10 @@ int main(int argc, char *argv[]) {
   testAnyLong(factory,&ev);
   testAnyString(factory,&ev);
   testAnyStruct(factory,&ev);
+  testAnyException(factory,&ev);
+  testSequenceOfAny(factory,&ev);
   testTypeCode(factory,&ev);
-
+  }
   CORBA_Object_release(factory, &ev);
   CORBA_Object_release((CORBA_Object)orb, &ev);
   g_assert(ev._major == CORBA_NO_EXCEPTION);
